*Gregory A. Bruich, Ph.D.
*Department of Economics, Harvard University
*Send corrections and suggestions to gbruich@fas.haravard.edu
  
*This .do file shows some examples of how to use the dfadjustSE.ado program to calculate 
*a bias-adjusted robust variance estimator with degrees of freedom correction for linear 
*regression with independent observations

*First, place the dfadjustSE.ado file into the current working directory

*Syntax: list dependent variable followed by regressors, just like the "regress y x1 x2" command
*By default, the program will report the results for the first regressor listed (e.g., x1 in the example above)
*This can be changed with the option coef(), which takes an integer between 0 and K as an argument
*Use coef(k) with k = 0 for the constant, k = 1 for the first regressor, k = 2 for the second regressor, etc
*The option reportreg will report results from the regression "regress y x1 x2, hc2"

*Load in nlsw88 data
sysuse nlsw88, clear

*Take a random sample of 15 observations
set seed 2110
sample 15, count

*Example 1: Report results for coefficient on grade
dfadjustSE wage grade age, coef(1) reportreg

*Example 2: Report results for coefficient on intercept
dfadjustSE wage grade age, coef(0) 

*Example 2: Report results for coefficient on age
dfadjustSE wage grade age, coef(2) 

*The results are stored as follows for ease of use
display "Bell and McCaffrey DOF:  " r(k_bm)   
display "t(K) quantile:  " r(t_k_bm)
display "Imbens and Kolesár (2016) adjusted HC2 standard error:  " r(adjse)
display "HC2 standard error:  " r(hc2_se)


*Example 1: Report results for coefficient on grade
dfadjustSE wage grade age, coef(1) reportreg

*Example 2: Report results for coefficient on intercept
dfadjustSE wage grade age, coef(0) 

*Example 2: Report results for coefficient on age
dfadjustSE wage grade age, coef(2) 

*The results are stored as follows for ease of use
display "Bell and McCaffrey DOF:  " r(k_bm)   
display "t(K) quantile:  " r(t_k_bm)
display "Imbens and Kolesár (2016) adjusted HC2 standard error:  " r(adjse)
display "HC2 standard error:  " r(hc2_se)

